export const sponsors = [
  {
    tier: 'Gold Sponsors',
    size: 'big',
    items: [
      {
        name: 'devowl',
        url: 'https://devowl.io/',
        img: '/img/devowl.io.svg'
      },
      {
        name: 'Magic',
        url: 'https://magic.dev/',
        img: '/img/magic.png'
      }
    ]
  }
];
